Alone:

For these, use ``:obj:`~.acos()```.

Or not alone:

For these, use ``:obj:`~.acos()```. The ``~`` makes it so that the
text in the rendered HTML only shows ``acos`` instead of the fully
qualified name.

Or even when there's two of them:

The first one: ``:obj:`foo```,
some noise: ``.``
and the second one: ``:obj:`foo```.
